fireworks.user_objects.dupefinders package — FireWorks 2.0.4 documentation

# fireworks.user_objects.dupefinders package

## Submodules

## fireworks.user_objects.dupefinders.dupefinder_exact module

class fireworks.user_objects.dupefinders.dupefinder_exact.DupeFinderExact

  Bases: `DupeFinderBase`

  This DupeFinder requires an exact spec match between FireWorks.

  query(spec)

    Returns the query for matching fireworks with non-zero launches and with exact matching specs.

    Parameters:

      spec (dict) – spec to check for duplicates

    Returns:

      mongo query

    Return type:

      dict

## Module contents